@@ -35,6 +35,12 @@ def get_itemsview(dic):
 
 def test_init():
     temp = SortedDict()
+    assert temp.key is None
+    temp._check()
+
+def test_init_key():
+    temp = SortedDict(negate)
+    assert temp.key == negate
     temp._check()
 
 def test_init_args():
@@ -316,6 +322,7 @@ def test_repr_subclass():
 def test_iloc():
     mapping = [(val, pos) for pos, val in enumerate(string.ascii_lowercase)]
     temp = SortedDict(mapping)
+    assert len(temp.iloc) == 26
     assert temp.iloc[0] == 'a'
     assert temp.iloc[-1] == 'z'
     assert temp.iloc[-3:] == ['x', 'y', 'z']
@@ -427,7 +434,7 @@ def test_valuesview():
     assert repr(values) == "SortedDict_values([0, 1])"
 
 @raises(ValueError)
-def test_valuesview():
+def test_values_view_index():
     if hexversion < 0x02070000: raise ValueError
 
     mapping = [(val, pos) for pos, val in enumerate(string.ascii_lowercase)]
@@ -558,6 +565,14 @@ def test_itemsview():
     items = SortedDict(mapping[:2]).viewitems()
     assert repr(items) == "SortedDict_items([('a', 0), ('b', 1)])"
 
+@raises(ValueError)
+def test_items_view_index():
+    if hexversion < 0x02070000: return
+    mapping = [(val, pos) for pos, val in enumerate(string.ascii_lowercase)]
+    temp = SortedDict(mapping[:13])
+    items = get_itemsview(temp)
+    items.index(('f', 100))
+
 def test_pickle():
     import pickle
     alpha = SortedDict(negate, zip(range(10000), range(10000)))
